//
// impressionistUI.h
//
// The header file for the UI part
//

#ifndef ImpressionistUI_h
#define ImpressionistUI_h

#include <FL/Fl.H>
#include <FL/Fl_Window.H>
#include <FL/fl_file_chooser.H>		// FLTK file chooser
#include <FL/Fl_Menu_Bar.H>
#include <FL/Fl_Value_Slider.H>
#include <FL/Fl_Choice.H>

class impressionistDoc;
#include "originalview.h"
#include "paintview.h"

#include "ImpBrush.h"

class ImpressionistUI {
public:
	ImpressionistUI();

	// The FLTK widgets
	Fl_Window*			m_mainWindow;
	Fl_Menu_Bar*		m_menubar;
								
	Fl_Window*			m_brushDialog;
	Fl_Slider*			m_BrushSizeSlider;
	Fl_Choice*			m_BrushTypeChoice;

	PaintView*			m_paintView;
	OriginalView*		m_origView;

	// member functions
	void				setDocument(ImpressionistDoc* doc);
	ImpressionistDoc*	getDocument();

	void show();
	void resize_windows(int w, int h);

	int  getSize();

private:
	ImpressionistDoc*	m_pDoc;		// pointer to document to communicate with the document

	int m_nSize;

// static class members
	static Fl_Menu_Item menuitems[];

	static ImpressionistUI* whoami(Fl_Menu_* o);

	static void cb_load_image(Fl_Menu_* o, void* v);	// callback are declared static
	static void cb_save_image(Fl_Menu_* o, void* v);
	static void cb_brushes(Fl_Menu_* o, void* v);
	static void cb_exit(Fl_Menu_* o, void* v);
	static void cb_about(Fl_Menu_* o, void* v);

	static void cb_exit2(Fl_Widget* o, void* v);

	static void cb_sizeSlides(Fl_Widget* o, void* v);
	static void cb_brushChoice(Fl_Widget* o, void* v);

	static Fl_Menu_Item brushTypeMenu[NUM_BRUSH_TYPE+1];
};

#endif
